@@ -1,4 +1,4 @@
-require 'mocha/options'
+require 'mocha/version'
 require 'mocha_standalone'
 require 'mocha/configuration'
 require 'mocha/integration'
