@@ -8,10 +8,4 @@ $:.unshift File.expand_path(File.join(File.dirname(__FILE__), 'unit'))
 $:.unshift File.expand_path(File.join(File.dirname(__FILE__), 'unit', 'parameter_matchers'))
 $:.unshift File.expand_path(File.join(File.dirname(__FILE__), 'acceptance'))
 
-require 'mocha/options'
-if $options['use_test_unit_gem']
-  require 'rubygems'
-  gem 'test-unit'
-end
-
-require 'test/unit'
\ No newline at end of file
+require 'test/unit'
